@@ -1,7 +1,8 @@
 from shinobi_client.client import ShinobiClient
-from shinobi_client.orms.user import ShinobiWrongPasswordError
+from shinobi_client.orms.user import ShinobiUserOrm, ShinobiWrongPasswordError
 from shinobi_client._common import ShinobiSuperUserCredentialsRequiredError
 from shinobi_client.orms.monitor import ShinobiMonitorOrm, ShinobiMonitorAlreadyExistsError
+from shinobi_client.api_key import ShinobiApiKey
 try:
     from shinobi_client.shinobi_controller import start_shinobi, ShinobiController
 except ImportError:
